<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://www.biuro.lt
 * @since      1.0.0
 *
 * @package    Biuro_Contacts
 * @subpackage Biuro_Contacts/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Biuro_Contacts
 * @subpackage Biuro_Contacts/public
 * @author     Biuro <info@biuro.lt>
 */
class Biuro_Contacts_Public {

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $plugin_name    The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $version    The current version of this plugin.
     */
    private $version;

    const FIELDS = [
        'employees-quick' => ['name', 'phone', 'email', 'agree']
    ];

    const DB_NAMES = [
        'employees-quick' => ['name', 'phone', 'email']
    ];

    /**
     * Initialize the class and set its properties.
     *
     * @since    1.0.0
     * @param      string    $plugin_name       The name of the plugin.
     * @param      string    $version    The version of this plugin.
     */
    public function __construct( $plugin_name, $version ) {

        $this->plugin_name = $plugin_name;
        $this->version = $version;

    }

    /**
     * Register the stylesheets for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_styles() {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Biuro_Contacts_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Biuro_Contacts_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */

        // wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/biuro-contacts-public.css', array(), $this->version, 'all' );

    }

    /**
     * Register the JavaScript for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_scripts() {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Biuro_Contacts_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Biuro_Contacts_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */

        // wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/biuro-contacts-public.js', array( 'jquery' ), $this->version, false );

    }


        // id mediumint(9) NOT NULL AUTO_INCREMENT,
        // created datetime DEFAULT '0000-00-00 00:00:00',
        // name tinytext,
        // surname tinytext,
        // email varchar(128) DEFAULT '',
        // phone varchar(128) DEFAULT '',
        // city varchar(255) DEFAULT '',
        // message longtext DEFAULT '',
        // cv text DEFAULT '',
        // updated datetime DEFAULT '0000-00-00 00:00:00',
        // confirm tinyint,
        // job_id int,

    // public function get_rows_from_db_as_associative_array() {
    //     global $wpdb;

    //     $sql = "SELECT * FROM `" . $wpdb->prefix . "biuro_employees` ORDER BY id DESC";

    //     return $wpdb->get_results( $sql, ARRAY_A );
    // }

    public static function insert_row_to_db($data) {
        global $wpdb;

        $table = $wpdb->prefix . 'biuro_employees';

        $format = array( '%s', '%s', '%s', '%s' );

        $wpdb->insert( $table, $data, $format );

        return $wpdb->insert_id;
    }

    public static function update_row_in_db($data, $insert_id) {
        global $wpdb;

        $table = $wpdb->prefix . 'biuro_employees';

        $format = array( '%s','%s', '%s', '%d', '%s' );

        $where = array('id' => $insert_id);

        $where_format = array('%d');

        return $wpdb->update( $table, $data, $where, $format, $where_format );
    }

    // public function use_prepare_db_query() {
    //     global $wpdb;
    //     $sql = "UPDATE $wpdb->posts SET post_parent = %d WHERE ID = %d AND post_status = %s";
    //     return $wpdb->query( $wpdb->prepare( $sql, 7, 15, 'static' ) );
    // }



    /**
     * Processes shortcode biuro-contacts--employees
     *
     * @param   array   $attr       The attributes from the shortcode
     *
     * @return  mixed   $output     Output of the buffer
     */
    public function employees_form( $atts ) {
        $response = false;

        ob_start();

        if ( isset( $_POST['action-submit'] ) ) :
            $response = true;
        endif;

        include_once('partials/biuro-contacts-public--employees.php');

        $output = ob_get_contents();

        ob_end_clean();

        return $output;
    } // employees_form()

    /**
     * Processes shortcode biuro-contacts--employees
     *
     * @param   array   $attr       The attributes from the shortcode
     *
     * @return  mixed   $output     Output of the buffer
     */
    public function employers_quick_form( $attr = array() ) {

        // $args = shortcode_atts(
        //     array(
        //         'arg1'   => 'arg1',
        //         'arg2'   => 'arg2',
        //     ),
        //     $atts
        // );

        $response = false;

        ob_start();

        if ( isset( $_POST['submit'] ) ) :
            $response = true;
        endif;

        include_once('partials/biuro-contacts-public--employers-quick.php');

        $output = ob_get_contents();

        ob_end_clean();

        return $output;
    } // employees_form()


    /**
     * Processes shortcode biuro-contacts--employers
     *
     * @param   array   $attr       The attributes from the shortcode
     *
     * @return  mixed   $output     Output of the buffer
     */
    public function employers_form( $attr = array() ) {
        $response = false;

        ob_start();

        if ( isset( $_POST['action-submit'] ) ) :
            $response = true;
        endif;

        include_once('partials/biuro-contacts-public--employers.php');

        $output = ob_get_contents();

        ob_end_clean();

        return $output;
    } // employers_form()

    /**
     * Processes shortcode biuro-contacts--position
     *
     * @param   array   $attr       The attributes from the shortcode
     *
     * @return  mixed   $output     Output of the buffer
     */
    public function position_form( $attr = array() ) {
        $response = false;

        ob_start();

        if ( isset( $_POST['action-submit'] ) ) :
            $response = true;
        endif;

        include_once('partials/biuro-contacts-public--position.php');

        $output = ob_get_contents();

        ob_end_clean();

        return $output;
    } // position_form()


    /**
     * May override the default upload path.
     * /wp-content/uploads/{folder}/
     *
     * @param   array   $dir
     * @return  array
     */
    function change_upload_dir( $dir ) {
        return array(
            'path'   => $dir['basedir'] . '/{folder}',
            'url'    => $dir['baseurl'] . '/{folder}',
            'subdir' => '/{folder}',
        ) + $dir;
    }

    public static function delete_transients( $str ) {
        foreach (static::FIELDS[$str] as $key) {
           unset($_SESSION[$str . '--' . $key . '-message']);
           unset($_SESSION[$str . '--' . $key . '-status']);
           unset($_SESSION[$str . '--' . $key . '-value']);
        }
    }

    public static function validate( $str, $key, $value, $post ) {
        $success = ['status' => 'success', 'message' => ''];
        $required = ['status' => 'error', 'message' => 'This field is required'];

        if ($str == 'employees-quick'):
            switch($key) {
            case 'name':

                return (!$value) ? $required : $success;

            case 'phone':
                if (!$value && !is_email($post['email'])):
                    return [
                        'status' => 'error',
                        'message' => 'Phone or email field is required'
                    ];
                endif;

                if (!$value):
                    return [
                        'status' => '',
                        'message' => ''
                    ];
                endif;

                return $success;

            case 'email':
                if (!$post['phone'] && !$value):
                    return [
                        'status' => 'error',
                        'message' => 'Email or phone field is required'
                    ];
                endif;

                if (!$post['phone'] && !is_email($value)):
                    return [
                        'status' => 'error',
                        'message' => 'Email format is incorrect'
                    ];
                else:

                    if (!$value):
                        return [
                            'status' => '',
                            'message' => ''
                        ];
                    endif;

                    return $success;
                endif;

            case 'agree':
                if ($value != "1"):
                    return [
                        'status' => 'error',
                        'message' => 'You have to agree with conditions'
                    ];
                endif;

                return $success;
            }

        endif;

        return $success;
    }

    public static function getValue( $key, $value ) {

        switch($key) {
        case 'name':
        case 'phone':
        case 'city':
            return sanitize_text_field($value);
        case 'email':
            return sanitize_email($value);
        case 'message':
            return sanitize_textarea_field($value);
        case 'cv':
            return sanitize_text_field($value);
        case 'agree':
        case 'confirm':
            return filter_var($value, FILTER_VALIDATE_INT) ? $value : 0;
        }

        return '';
    }

    public static function set_transients( $str, $post ) {
        $canSubmit = true;

        $data = [
            'created' => current_time('Y-m-d H:i:s')
        ];
        
        
        foreach (static::FIELDS[$str] as $key) {
            $value = static::getValue($key, $post[$key]);
            $validation = static::validate($str, $key, $value, $post);

            if ($validation['status'] == 'error'):
                $canSubmit = false;
            endif;

            if ( in_array($key, static::DB_NAMES[$str])):
                $data[$key] = $value;
            endif;

            $_SESSION[$str . '--' . $key . '-value'] = $value;
            $_SESSION[$str . '--' . $key . '-status'] = $validation['status'];
            $_SESSION[$str . '--' . $key . '-message'] = $validation['message'];
        }

        if ($canSubmit):
            $insert_id = static::insert_row_to_db($data);

            $_SESSION[$str . '--step'] = 2;
            $_SESSION[$str . '--id'] = $insert_id;
        endif;
    }

    /**
     * Processes shortcode biuro-contacts--employees
     *
     * @param   array   $attr       The attributes from the shortcode
     *
     * @return  mixed   $output     Output of the buffer
     */
    public function employees_quick_form( $attr = array() ) {
        ob_start();

        include_once('partials/biuro-contacts-public--employees-quick.php');

        $output = ob_get_contents();

        ob_end_clean();

        static::delete_transients('employees-quick');

        return $output;
    } // employees_form()

    public function employees_quick_post() {

        $nonce = $_POST['_wpnonce'];
        $referer = $_POST['_wp_http_referer'];
    
    
        if ( !isset( $nonce ) || !wp_verify_nonce($nonce, 'employees_quick_post_nonce' ) ) {
            wp_redirect( $referer );
            exit;
        }

        unset($_SESSION['employees-quick--step']);

        if ($_POST['submit'] == "1"):

            static::set_transients('employees-quick', $_POST);

        elseif ($_POST['submit'] == "2" && $_SESSION['employees-quick--id']):

            $data = [
                'city' => static::getValue('city', $_POST['city']),
                'message' => static::getValue('message', $_POST['message']),
                //'cv' => static::getValue('cv', $_POST['cv']),
                'confirm' => static::getValue('confirm', $_POST['confirm']),
                'updated' => current_time('Y-m-d H:i:s')
            ];
            
            # upload file
            if($_FILES) {
                # gali nusirody: 'mimes' => array('csv' => 'text/csv')
                $movefile = wp_handle_upload($_FILES['cv'], [
                    'test_form' => false,
                    //'unique_filename_callback' => 'custom_file_name'
                ]);
                
                if ( $movefile && ! isset( $movefile['error'] ) ) {
                    $data['cv'] = static::getValue('cv', $movefile['url']);
                } else {
                    $_SESSION['file_error'] = $movefile['error'];
                }                
            }
            
            static::update_row_in_db($data, $_SESSION['employees-quick--id']);
        endif;


        wp_redirect( $referer );
        exit;
    }
    
    #function custom_file_name($dir, $name, $ext){
    #    return $name.$ext;
   # }

    public function employers_quick_post() {
        debug($_POST); //$_POST variables should be accessible now

        //Optional: Now you can redirect the user to your confirmation page using wp_redirect()
        // ob_start();
        // wp_redirect($_POST['_wp_http_referer']);
        exit;

        // wp_redirect(admin_url('admin.php?page=' . $_POST['_wp_http_referer']));
        // die();
        //apparently when finished, die(); is required.
    }
    
    /**
    * @method getContacts
    * get contacts data from DB for API endpoint "contacts" endpoint;
    * @param WP_REST_Request $request
    * @return json;
    */
    public static function getContacts(WP_REST_Request $request)
    {    
        global $wpdb;
        $params = $request->get_params();

        if ( !$params ) {
            exit;
        }
        
        $from = (string) $params['from'];
        $orderBy = (string) $params['by'];
                
        if(!$from || !in_array($orderBy, ['created', 'updated'])) {
            exit;
        }
         
        $sql = "SELECT * FROM `" . $wpdb->prefix . "biuro_employees` 
            where ". $orderBy. " >= '". $from. "' ORDER BY ". $orderBy ." DESC LIMIT 50";
        return $wpdb->get_results($sql, ARRAY_A);
    }
}
