import Awesomplete from './vendor/awesomplete';

(global => {
    const container = document.getElementById('cookie-warning');
    const btnAgree = document.getElementById('cookie-agree');
    const btnClose = document.getElementById('cookie-close');
    const agreed = (useLS()) ? localStorage.getItem('biuro-agree') : false;

    function useLS () {
        var mod = 'a';
        try {
            localStorage.setItem(mod, mod);
            localStorage.removeItem(mod);
            return true;
        } catch (e) {
            return false;
        }
    }

    if (!container || !btnAgree || !btnClose || agreed) {
        return;
    }

    container.style.display = 'block';

    btnAgree.addEventListener('click', () => {
        if (useLS()) {
            localStorage.setItem('biuro-agree', 'true');
        }
        container.style.display = 'none';
    });

    btnClose.addEventListener('click', () => {
        container.style.display = 'none';
    });
})(window);

if (module.hot) {
    module.hot.accept();
}

(global => {
    const node = document.getElementById('js-divisions-map');

    if (!node) {
        return;
    }

    fetch('/wp-json/api/v1/divisions?lang=' + node.dataset.lang)
        .then((t) => t.json())
        .then((data) => {
            initDivisionsMap(node, data);
        });
})(window);

function setMarkers (map, divisions) {
    var info;
    var bounds = new window.google.maps.LatLngBounds();

    for (var i = 0; i < divisions.length; i++) {
        const division = divisions[i];
        const pos = new window.google.maps.LatLng(division.lat, division.lng);

        var marker = new window.google.maps.Marker({
            position: pos,
            map: map,
            icon: '/wp-content/themes/biuro/i/maps/pin.png',
            title: division.title
        });

        bounds.extend(pos);

        marker['content'] = division.content;

        window.google.maps.event.addListener(marker, 'click', function () {
            if (info) {
                info.close();
            }

            info = new window.google.maps.InfoWindow({
                content: this.content
            });

            info.open(map, this);
        });
    }

    map.fitBounds(bounds);
}

function initDivisionsMap (node, data) {
    if (!window.google) {
        setTimeout(() => { initDivisionsMap(node, data); }, 250);
        return;
    }

    const map = new window.google.maps.Map(node, {
        mapTypeId: window.google.maps.MapTypeId.ROADMAP
    });

    window.google.maps.event.addListenerOnce(map, 'bounds_changed', function () {
        if (this.getZoom() > 15) {
            this.setZoom(14);
        }
    });

    let divisions = [];

    const region = document.querySelector('.js-active-region');
    const ID = (region && region.dataset.id) ? region.dataset.id : '';

    if (data[ID]) {
        divisions = data[ID];
    } else {
        Object.keys(data).forEach((key) => {
            const division = data[key];
            if (key.substr(0, 4) === 'city') {
                divisions = divisions.concat(division);
            }
        });
    }

    setMarkers(map, divisions.filter((d) => { return d.lat && d.lng; }));
}

const search = document.getElementById('search');
const city = document.getElementById('search-city');
const query = document.getElementById('search-query');

const cityBox = new Awesomplete(city, {
    minChars: 0,
    sort: false
    // data: (item, input) => {
    //     console.error('----------');
    //     console.dir(item);
    //     console.dir(input);
    //     return { label: item.value, value: item.name };
    // },
    // replace: function(text) {
    //     console.error('text');
    //     console.dir(text);
    //     // var hidden = document.querySelector('[name="' + this.input.dataset.name + '"]');

    //     // this.input.value = text.label;

    //     // if (!hidden) {
    //     //     return;
    //     // }

    //     // hidden.value = text.value;

    //     // if (hidden.classList.contains('js-trigger-datalist')) {
    //     //     hidden.dispatchEvent(new Event('change', {
    //     //         'bubbles': true,
    //     //         'cancelable': true
    //     //     }));
    //     // }

    //     // hidden.dispatchEvent(event);
    // }
// });
});

city.addEventListener('focus', () => {
    cityBox.evaluate();
});

const queryBox = new Awesomplete(query, {
    minChars: 0,
    sort: false
});

query.addEventListener('focus', () => {
    queryBox.evaluate();
});

if (search) {
    search.addEventListener('submit', (e) => {
        if (!city.value && !query.value) {
            city.focus();
            e.preventDefault();
        }
    }, false);
}

// function initDatalist() {

//     var nodes = document.querySelectorAll('.js-datalist, .js-datalist-ajax'),
//         node,
//         getHidden = function(node) {
//             return document.querySelector('[name="' + node.dataset.name + '"]');
//         },
//         event = new Event('input', {
//             'bubbles': true,
//             'cancelable': true
//         });

//     for (var i = 0; i < nodes.length; i++) {
//         node = nodes[i];

//         if (node.comboplete) {
//             return;
//         }

//         node.comboplete = new Awesomplete(node, {
//             minChars: 0,
//             maxItems: 50,
//             replace: function(text) {

//                 var hidden = getHidden(this.input);

//                 this.input.value = text.label;

//                 if (!hidden) {
//                     return;
//                 }

//                 hidden.value = text.value;

//                 if (hidden.classList.contains('js-trigger-datalist')) {
//                     hidden.dispatchEvent(new Event('change', {
//                         'bubbles': true,
//                         'cancelable': true
//                     }));
//                 }

//                 hidden.dispatchEvent(event);


//             }
//         });

//         node.addEventListener('click', function() {
//             if (this.comboplete.ul.childNodes.length === 0 || !node.value) {
//                 this.comboplete.minChars = 0;
//                 this.comboplete.evaluate();
//             }
//             else if (this.comboplete.ul.hasAttribute('hidden')) {
//                 this.comboplete.open();
//             }
//             else {
//                 this.comboplete.close();
//             }
//         });

//         node.addEventListener('keyup', function(e) {
//             var code = e.keyCode || 0;

//             if (code === 13) {
//                 if (this.comboplete.ul.childNodes.length === 1) {
//                     this.comboplete.select(this.comboplete.ul.childNodes[0]);
//                 }
//             }
//         });

//         node.addEventListener('input', function() {
//             var value = this.value,
//                 exists = false,
//                 hidden;

//             this.comboplete.ul.childNodes.forEach(function(n) {
//                 if (n.innerText === value) {
//                     exists = true;
//                 }
//             });

//             if (exists) {
//                 return;
//             }

//             hidden = getHidden(this);

//             if (!hidden) {
//                 return;
//             }

//             hidden.value = '';

//             hidden.dispatchEvent(event);
//         })
//     }
// }
